summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorSébastien Helleu <flashcode@flashtux.org>2019-05-12 20:18:59 +0200
committerSébastien Helleu <flashcode@flashtux.org>2019-05-12 21:39:22 +0200
commitabe85999d81b5d8676718cbe7bf60d2ddc9a2efe (patch)
treeb6af20ecd49f5c8638d310c54bccac63befcbcd4
parentdf3848e1f0523c79fb9334af795121fc20579660 (diff)
downloadweechat-abe85999d81b5d8676718cbe7bf60d2ddc9a2efe.zip
relay: rename function relay_config_create_option_port to relay_config_create_option_port_path
-rw-r--r--src/plugins/relay/relay-command.c2
-rw-r--r--src/plugins/relay/relay-config.c16
-rw-r--r--src/plugins/relay/relay-config.h10
3 files changed, 14 insertions, 14 deletions
diff --git a/src/plugins/relay/relay-command.c b/src/plugins/relay/relay-command.c
index c63ad4a3d..20992b0fd 100644
--- a/src/plugins/relay/relay-command.c
+++ b/src/plugins/relay/relay-command.c
@@ -228,7 +228,7 @@ relay_command_relay (const void *pointer, void *data,
/* check if we're expecting a path or a port */
port_path_section = (strncmp (argv[2], "unix.", 5) == 0) ?
relay_config_section_path : relay_config_section_port;
- if (relay_config_create_option_port (
+ if (relay_config_create_option_port_path (
NULL, NULL,
relay_config_file,
port_path_section,
diff --git a/src/plugins/relay/relay-config.h b/src/plugins/relay/relay-config.h
index 52ab8ae64..bef7fe19c 100644
--- a/src/plugins/relay/relay-config.h
+++ b/src/plugins/relay/relay-config.h
@@ -68,11 +68,11 @@ extern int relay_config_check_network_totp_secret (const void *pointer,
void *data,
struct t_config_option *option,
const char *value);
-extern int relay_config_create_option_port (const void *pointer, void *data,
- struct t_config_file *config_file,
- struct t_config_section *section,
- const char *option_name,
- const char *value);
+extern int relay_config_create_option_port_path (const void *pointer, void *data,
+ struct t_config_file *config_file,
+ struct t_config_section *section,
+ const char *option_name,
+ const char *value);
extern int relay_config_check_path_len (const char *path);
extern int relay_config_init ();
extern int relay_config_read ();
diff --git a/src/plugins/relay/relay-config.c b/src/plugins/relay/relay-config.c
index 0f0b7b05b..e133f56a8 100644
--- a/src/plugins/relay/relay-config.c
+++ b/src/plugins/relay/relay-config.c
@@ -622,15 +622,15 @@ relay_config_delete_port_cb (const void *pointer, void *data,
}
/*
* Callback called when an option is created in section "port".
*/
int
-relay_config_create_option_port (const void *pointer, void *data,
- struct t_config_file *config_file,
- struct t_config_section *section,
- const char *option_name,
- const char *value)
+relay_config_create_option_port_path (const void *pointer, void *data,
+ struct t_config_file *config_file,
+ struct t_config_section *section,
+ const char *option_name,
+ const char *value)
{
int rc, protocol_number, ipv4, ipv6, ssl, unix_socket;
char *error, *protocol, *protocol_args;
@@ -1149,7 +1149,7 @@ relay_config_init ()
NULL, NULL, NULL,
NULL, NULL, NULL,
NULL, NULL, NULL,
- &relay_config_create_option_port, NULL, NULL,
+ &relay_config_create_option_port_path, NULL, NULL,
NULL, NULL, NULL);
if (!ptr_section)
{
@@ -1167,7 +1167,7 @@ relay_config_init ()
NULL, NULL, NULL,
NULL, NULL, NULL,
NULL, NULL, NULL,
- &relay_config_create_option_port, NULL, NULL,
+ &relay_config_create_option_port_path, NULL, NULL,
NULL, NULL, NULL);
if (!ptr_section)
{
@@ -622,15 +622,15 @@ relay_config_delete_port_cb (const void *pointer, void *data,
}
/*
- * Callback called when an option is created in section "port".
+ * Callback called when an option is created in section "port" or "path".
*/
int